@@ -14,7 +14,7 @@ from copy import copy
 
 __major__ = 1
 __minor__ = 5
-__bugfix__ = 2
+__bugfix__ = 3
 
 __version__ = '%s.%s.%s' % (__major__, __minor__, __bugfix__)
 
@@ -103,6 +103,16 @@ default_config = {
 }
 
 
+class MissingConfigurationError(KeyError):
+    """
+    Exception that will be raised if the asked Key is not configured.
+    """
+    def __init__(self, key):
+        super(MissingConfigurationError, self).__init__(
+            'No configuration named "%s". Please specify in '
+            'settings or register at runtime.' % key)
+
+
 class DIConfig(namedtuple('DIConfigBase', default_config.keys())):
     """
     This type is used for the internal configuration. Each configuraiton dict
@@ -477,8 +487,17 @@ class DIContainer(object):
         if name in self.singletons:
             return self.singletons[name]
 
-        # load information to create the instance
-        conf = self.settings[name]
+        try:
+            # load information to create the instance
+            conf = self.settings[name]
+        except KeyError:
+            # if htere is a parent given, check if there is a configuration
+            # for this name. otherwise raise an exception.
+            if self.parent is not None:
+                return self.parent.resolve(name)
+            else:
+                raise MissingConfigurationError(name)
+
         singleton = conf.singleton
         if isinstance(conf.type, string_types):
             type_ = self._resolve_type(conf.type)
@@ -535,7 +554,16 @@ class DIContainer(object):
 
         self.event_dispatcher.before_resolve_type(name=name)
 
-        conf = self.settings[name]
+        try:
+            # try to resolve the configuration by name.
+            conf = self.settings[name]
+        except KeyError:
+            # if htere is a parent given, check if there is a configuration
+            # for this name. otherwise raise an exception.
+            if self.parent is not None:
+                return self.parent.resolve(name)
+            else:
+                raise MissingConfigurationError(name)
         type_ = self._resolve_type(conf.type)
 
         self.event_dispatcher.after_resolve_type(name=name, type=type_)
@@ -634,12 +662,17 @@ class DIContainer(object):
         :returns: object
         :rtype: object
         """
-        if name not in self.settings:
+
+        try:
+            # try to resolve in this container.
+            return self.resolve(name)
+        except MissingConfigurationError as error:
+            # If this containers has a parent container lookup there
+            # or reraise the exception.
             if self.parent is not None:
                 return self.parent.resolve(name)
-            raise AttributeError(
-                'no component named "%s". please adjust in settings.' % name)
-        return self.resolve(name)
+            else:
+                raise error
 
     def inject(self, force=False, **inject_kwargs):
         """
